Compat. utilities - kombu.utils.compat — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# Compat. utilities - kombu.utils.compat

class `kombu.utils.compat.` `CompatOrderedDict`(*args, **kwds)

  Dictionary that remembers insertion order

  `clear`()

    od.clear() -> None. Remove all items from od.

  `copy`()

    od.copy() -> a shallow copy of od

  classmethod `fromkeys`(iterable, value=None)

    OD.fromkeys(S[, v]) -> New ordered dictionary with keys from S and values equal to v (which defaults to None).

  `items`()
  `iteritems`()
  `iterkeys`()
  `itervalues`()
  `keys`()
  `pop`(key, default=<object object at 0x10252f750>)
  `popitem`(last=True)

    od.popitem() -> (k, v)

    Return and remove a (key, value) pair. Pairs are returned in LIFO order if last is true or FIFO order if false.

  `setdefault`(key, default=None)
  `update`(other=(), **kwds)
  `values`()

class `kombu.utils.compat.` `LifoQueue`(maxsize=0)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »